@@ -1,9 +1,8 @@
-use to_unit::ToUnit;
-// or, `use to_unit::ToUnit as __` for ultra lzay persons!
-
 #[test]
 fn match_arms_to_easily()
 {
+ use to_unit::ToUnit; // <-- here
+
  use std::collections::HashMap;
  let mut x = HashMap::<String, i32>::new();
  x.insert("neko".to_string(), 123);
@@ -21,3 +20,19 @@ fn match_arms_to_easily()
  // I don't like the multi-line behaviors, so I made the __ lib.
  //
 }
+
+/// Or, `use to_unit::__` for ultra lazy persons!
+#[test]
+fn for_ultra_lazy_persons()
+{
+ use to_unit::__; // <-- here
+
+ use std::collections::HashMap;
+ let mut x = HashMap::<String, i32>::new();
+ x.insert("neko".to_string(), 123);
+ match x.get_mut("neko")
+ {
+  Some(v) => *v = 222,
+  None => x.insert("neko".to_string(), 222).__() // <-- here!
+ }
+}
